@@ -3,7 +3,7 @@ from investing_algorithm_framework.configuration.settings import Config
 from investing_algorithm_framework.configuration.validator import \
     ConfigValidator
 from investing_algorithm_framework.configuration.setup import create_app, \
-    setup_config, setup_database
+    setup_config, setup_database, setup_logging
 from investing_algorithm_framework.configuration.constants import \
     RESOURCES_DIRECTORY, LOG_LEVEL
 
@@ -18,5 +18,6 @@ __all__ = [
     "setup_database",
     "setup_config",
     "RESOURCES_DIRECTORY",
-    "LOG_LEVEL"
+    "LOG_LEVEL",
+    "setup_logging"
 ]
