@@ -2,8 +2,8 @@ from enum import Enum
 
 
 class OrderType(Enum):
-    SELL = 'SELL'
-    BUY = 'BUY'
+    LIMIT = 'LIMIT'
+    MARKET = 'MARKET'
 
     @staticmethod
     def from_string(value: str):
