@@ -1,7 +1,8 @@
 import csv
 import shutil
-from typing import Dict, List
 import tempfile
+from typing import Dict, List
+
 from investing_algorithm_framework.core.exceptions import OperationalException
 
 
@@ -35,10 +36,12 @@ def append_dict_as_row_to_csv(
 def get_total_amount_of_rows(file_path: str):
     file = open(file_path)
     reader = csv.reader(file)
-    return len(list(reader))
+    rows_count = len(list(reader))
+    file.close()
+    return rows_count
 
 
-# Function to convert a csv to a list of data
+# Function to convert a csv to a list of data_provider
 def csv_to_list(csv_path: str, strip_column_headers: bool = False) -> List:
     data = []
     with open(csv_path, "r") as csv_f:
